pub(crate) struct ValueInterface {
node: PlatformNode,
}Fields
node: PlatformNodeImplementations
Sourceimpl ValueInterface
impl ValueInterface
fn minimum_value(&self) -> Result<f64>
fn maximum_value(&self) -> Result<f64>
fn minimum_increment(&self) -> Result<f64>
fn current_value(&self) -> Result<f64>
fn set_current_value(&mut self, value: f64) -> Result<()>
Sourceimpl ValueInterface
impl ValueInterface
Sourcepub async fn minimum_value_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn minimum_value_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
MinimumValue property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn maximum_value_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn maximum_value_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
MaximumValue property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn minimum_increment_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn minimum_increment_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
MinimumIncrement property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn current_value_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn current_value_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
CurrentValue property.
This method should be called if a property value changes outside its setter method.